#include <Servo.h>          // servo
#include <NewPing.h>        // Ultrasonic sensor 

#include <Wire.h>                        
#include <SPI.h>
#include <Adafruit_GFX.h>                
#include <Adafruit_SH1106.h>    

#define OLED_RESET 4
#define SH1106_LCDHEIGHT 64

#include "eyes.h"

Adafruit_SH1106 display(OLED_RESET);
 
// L298N motor pin
const int LeftMotorForward = 6;
const int LeftMotorBackward = 7;
const int RightMotorForward = 5;
const int RightMotorBackward = 4;

// sensor pin
#define trig_pin A1 //analog input 1
#define echo_pin A2 //analog input 2

#define maximum_distance 200
boolean goesForward = false;
int distance = 100;


NewPing sonar(trig_pin, echo_pin, maximum_distance); 
Servo servo_motor; 

#if (SH1106_LCDHEIGHT != 64)
#error("Height incorrect, please fix Adafruit_SSD1306.h!");
#endif

void setup(){
  Serial.begin(9600);
  display.begin(SH1106_SWITCHCAPVCC, 0x3C); // adresa  
  display.clearDisplay(); 
  delay(3000);
  
  display.clearDisplay();
  display.drawBitmap(0,0,otevrene_oko,128,64,WHITE);
  display.display();
  delay(500);

  display.clearDisplay();
  display.drawBitmap(0,0,zavrene_oko,128,64,WHITE);
  display.display();
  delay(200);

  display.clearDisplay();
  display.drawBitmap(0,0,otevrene_oko,128,64,WHITE);
  display.display();
  delay(500);
  
  pinMode(RightMotorForward, OUTPUT);
  pinMode(LeftMotorForward, OUTPUT);
  pinMode(LeftMotorBackward, OUTPUT);
  pinMode(RightMotorBackward, OUTPUT);
  
  servo_motor.attach(11); // servo pin

  servo_motor.write(115);
  delay(2000);
  distance = readPing();
  delay(100);
  distance = readPing();
  delay(100);
  distance = readPing();
  delay(100);
  distance = readPing();
  delay(100);
}

void loop(){

  int distanceRight = 0;
  int distanceLeft = 0;
  delay(50);

  if (distance <= 20){
    moveStop();
    delay(300);
    moveBackward();
    delay(400);
    moveStop();
    delay(300);
    distanceRight = lookRight();
    delay(300);
    distanceLeft = lookLeft();
    delay(300);

    if (distance >= distanceLeft){
      turnRight();
      moveStop();
    }
    else{
      turnLeft();
      moveStop();
    }
  }
  else{
    moveForward(); 
  }
    distance = readPing();
}

int lookRight(){  
  servo_motor.write(50);
  delay(500);
  int distance = readPing();
  delay(100);
  servo_motor.write(115);
  return distance;
}

int lookLeft(){
  servo_motor.write(170);
  delay(500);
  int distance = readPing();
  delay(100);
  servo_motor.write(115);
  return distance;
  delay(100);
}

int readPing(){
  delay(70);
  int cm = sonar.ping_cm();
  if (cm==0){
    cm=250;
  }
  return cm;
}

void moveStop(){    // stop
  
  digitalWrite(RightMotorForward, LOW);
  digitalWrite(LeftMotorForward, LOW);
  digitalWrite(RightMotorBackward, LOW);
  digitalWrite(LeftMotorBackward, LOW);

  display.clearDisplay();
  display.drawBitmap(0,0,otevrene_oko,128,64,WHITE);
  display.display();
  delay(500);

  display.clearDisplay();
  display.drawBitmap(0,0,zavrene_oko,128,64,WHITE);
  display.display();
  delay(200);

  display.clearDisplay();
  display.drawBitmap(0,0,otevrene_oko,128,64,WHITE);
  display.display();
  delay(500);
}

void moveForward(){   // posunout vpřed

  if(!goesForward){

    goesForward=true;
    
    digitalWrite(LeftMotorForward, HIGH);
    digitalWrite(RightMotorForward, HIGH);
  
    digitalWrite(LeftMotorBackward, LOW);
    digitalWrite(RightMotorBackward, LOW);


  }
}

void moveBackward(){  // dozadu

  goesForward=false;

  digitalWrite(LeftMotorBackward, HIGH);
  digitalWrite(RightMotorBackward, HIGH);
  
  digitalWrite(LeftMotorForward, LOW);
  digitalWrite(RightMotorForward, LOW);

  display.clearDisplay();
  display.drawBitmap(0,0,otevrene_oko,128,64,WHITE);
  display.display();
  delay(500);

  display.clearDisplay();
  display.drawBitmap(0,0,zavrene_oko,128,64,WHITE);
  display.display();
  delay(200);

  display.clearDisplay();
  display.drawBitmap(0,0,otevrene_oko,128,64,WHITE);
  display.display();
  delay(500);
}

void turnRight(){   // odbočit vpravo

  digitalWrite(LeftMotorForward, HIGH);
  digitalWrite(RightMotorBackward, HIGH);
  
  digitalWrite(LeftMotorBackward, LOW);
  digitalWrite(RightMotorForward, LOW);

  delay(500);
  
  digitalWrite(LeftMotorForward, HIGH);
  digitalWrite(RightMotorForward, HIGH);
  
  digitalWrite(LeftMotorBackward, LOW);
  digitalWrite(RightMotorBackward, LOW);
 
  display.clearDisplay();
  display.drawBitmap(0,0,vpravo,128,64,WHITE);
  display.display();
  delay(500);

  display.clearDisplay();
  display.drawBitmap(0,0,polootevrene_oko,128,64,WHITE);
  display.display();
  delay(200);

  display.clearDisplay();
  display.drawBitmap(0,0,vpravo,128,64,WHITE);
  display.display();
  delay(500);
  

  
}

void turnLeft(){    // odbočit vlevo

  digitalWrite(LeftMotorBackward, HIGH);
  digitalWrite(RightMotorForward, HIGH);
  
  digitalWrite(LeftMotorForward, LOW);
  digitalWrite(RightMotorBackward, LOW);

  delay(500);
  
  digitalWrite(LeftMotorForward, HIGH);
  digitalWrite(RightMotorForward, HIGH);
  
  digitalWrite(LeftMotorBackward, LOW);
  digitalWrite(RightMotorBackward, LOW);

  display.clearDisplay();
  display.drawBitmap(0,0,vlevo,128,64,WHITE);
  display.display();
  delay(500);

  display.clearDisplay();
  display.drawBitmap(0,0,polootevrene_oko,128,64,WHITE);
  display.display();
  delay(200);

  display.clearDisplay();
  display.drawBitmap(0,0,vlevo,128,64,WHITE);
  display.display();
  delay(500);
}
